@@ -56,12 +56,13 @@ otrplayerfile::otrplayerfile()
    QString  dir_str;
    QDir     dir;
 
+   convertDirectory();
 
    if (getenv("HOME"))
       dir_str = getenv("HOME");
    dir_str.append("/MyDocs/");
    dir.mkdir(dir_str);
-   dir_str.append("otrplayer/");
+   dir_str.append(".otrplayer/");
    dir.mkdir(dir_str);
    dir_str.append("otrplayer.cfg");
 
@@ -77,6 +78,29 @@ otrplayerfile::~otrplayerfile()
    delete _file;
 }
 
+// If otrplayer directory is present then convert it to .otrplayer
+void
+otrplayerfile::convertDirectory()
+{
+   QString  old_dir;
+   QString  new_dir;
+   QDir  dir;
+
+   if (getenv("HOME"))
+   {
+      old_dir = getenv("HOME");
+      new_dir = getenv("HOME");
+   }
+   old_dir.append("/MyDocs/otrplayer/");
+   new_dir.append("/MyDocs/.otrplayer/");
+
+   // IF the directory exists then we move it
+   if (dir.exists(old_dir) == true)
+   {
+      dir.rename(old_dir, new_dir);
+   }
+}
+
 
 void
 otrplayerfile::process(
