@@ -176,6 +176,13 @@ aflibGstFile::afcreate(
 {
    aflibStatus status = AFLIB_SUCCESS;
    aflibConfig output_cfg(config);
+	GstElement  *pipeline;
+
+   // create pipeline
+   pipeline = gst_pipeline_new ("my-pipeline");
+
+
+
 
 
    _create_mode = TRUE;
